@@ -450,12 +450,12 @@ char *slideshow_create_name(feh_file * file, winwidget winwid)
 	return(s);
 }
 
-void feh_action_run(feh_file * file, char *action)
+void feh_action_run(feh_file * file, char *action, winwidget winwid)
 {
 	if (action) {
 		char *sys;
 		D(("Running action %s\n", action));
-		sys = feh_printf(action, file, NULL);
+		sys = feh_printf(action, file, winwid);
 
 		if (opt.verbose && !opt.list && !opt.customlist)
 			fprintf(stderr, "Running action -->%s<--\n", sys);
@@ -615,6 +615,8 @@ char *feh_printf(char *str, feh_file * file, winwidget winwid)
 				if (winwid) {
 					snprintf(buf, sizeof(buf), "%.2f", winwid->zoom);
 					strncat(ret, buf, sizeof(ret) - strlen(ret) - 1);
+				} else {
+					strncat(ret, "1.00", sizeof(ret) - strlen(ret) - 1);
 				}
 				break;
 			case '%':
